Index: /applications/editors/josm/plugins/smed2/src/seamap/SeaMap.java
===================================================================
--- /applications/editors/josm/plugins/smed2/src/seamap/SeaMap.java	(revision 30163)
+++ /applications/editors/josm/plugins/smed2/src/seamap/SeaMap.java	(revision 30164)
@@ -24,5 +24,6 @@
 		ANON,	// Edge inner nodes
 		ISOL,	// Node not part of Edge
-		CONN	// Edge first and last nodes
+		CONN,	// Edge first and last nodes
+		DPTH	// Member of sounding array
 	}
 
@@ -31,4 +32,5 @@
 		public double lon;	// Longitude
 		public Nflag flg;		// Role of node
+		public double val;	// Sounding value
 
 		public Snode() {
@@ -36,4 +38,5 @@
 			lat = 0;
 			lon = 0;
+			val = 0;
 		}
 		public Snode(double ilat, double ilon) {
@@ -41,4 +44,5 @@
 			lat = ilat;
 			lon = ilon;
+			val = 0;
 		}
 		public Snode(double ilat, double ilon, Nflag iflg) {
@@ -46,4 +50,19 @@
 			lon = ilon;
 			flg = iflg;
+			val = 0;
+		}
+		public Snode(double ilat, double ilon, Nflag iflg, double ival) {
+			lat = ilat;
+			lon = ilon;
+			flg = iflg;
+			val = ival;
+		}
+	}
+
+	public class Sarray {	// A sounding array
+		public ArrayList<Long> nodes; // Sounding nodes
+
+		public Sarray() {
+			nodes = new ArrayList<Long>();
 		}
 	}
@@ -122,4 +141,10 @@
 	public class NodeTab extends HashMap<Long, Snode> {
 		public NodeTab() {
+			super();
+		}
+	}
+
+	public class DpthTab extends HashMap<Long, Snode> {
+		public DpthTab() {
 			super();
 		}
@@ -177,4 +202,5 @@
 
 	public NodeTab nodes;
+	public DpthTab depths;
 	public EdgeTab edges;
 	public AreaTab areas;
